@@ -1,5 +1,5 @@
 #' @title Bar plot of the average fold change of the target genes
-#' @description Bar plot of the average fold change for target genes along with the 95 percent CI and significance
+#' @description Bar plot of the average fold change (FC) of the target genes along with the 95 percent CI and significance in a two-level experimental condition.
 #' @details The \code{qpcrTTESTplot} function applies a t.test based analysis to any number of genes along with one reference gene, that have been evaluated under control and treatment conditions, and returns the bar plot of the average fold change for target genes along with the 95\% CI and significance.
 #' @author Ghader Mirzaghaderi
 #' @export qpcrTTESTplot
@@ -133,6 +133,7 @@ qpcrTTESTplot <- function(x,
     theme(legend.text = element_text(colour = "black", size = fontsize),
           legend.background = element_rect(fill = "transparent"))
 
-  print(p)
+  out <- list(plot = p)
+  return(out)
 }
 
